# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class StorageClassEnum(str, Enum):
    """
    * `pulpcore.app.models.storage.FileSystem` - Use local filesystem as storage * `storages.backends.s3boto3.S3Boto3Storage` - Use Amazon S3 as storage [deprecated] * `storages.backends.s3.S3Storage` - Use Amazon S3 as storage * `storages.backends.azure_storage.AzureStorage` - Use Azure Blob as storage * `pulp_service.app.storage.OCIStorage` - Use OCI as storage
    """

    """
    allowed enum values
    """
    PULPCORE_DOT_APP_DOT_MODELS_DOT_STORAGE_DOT_FILE_SYSTEM = 'pulpcore.app.models.storage.FileSystem'
    STORAGES_DOT_BACKENDS_DOT_S3BOTO3_DOT_S3_BOTO3_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
    STORAGES_DOT_BACKENDS_DOT_S3_DOT_S3_STORAGE = 'storages.backends.s3.S3Storage'
    STORAGES_DOT_BACKENDS_DOT_AZURE_STORAGE_DOT_AZURE_STORAGE = 'storages.backends.azure_storage.AzureStorage'
    PULP_SERVICE_DOT_APP_DOT_STORAGE_DOT_OCI_STORAGE = 'pulp_service.app.storage.OCIStorage'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of StorageClassEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_service.api.api_rds_connection_tests_api import ApiRdsConnectionTestsApi


class TestApiRdsConnectionTestsApi(unittest.TestCase):
    """ApiRdsConnectionTestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApiRdsConnectionTestsApi()

    def tearDown(self) -> None:
        pass

    def test_get(self) -> None:
        """Test case for get

        """
        pass

    def test_post(self) -> None:
        """Test case for post

        Dispatch RDS connection tests
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from pulpcore.client.pulp_service.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_service.models.domain import Domain
from pulpcore.client.pulp_service.models.domain_response import DomainResponse
from pulpcore.client.pulp_service.models.my_permissions_response import MyPermissionsResponse
from pulpcore.client.pulp_service.models.nested_role import NestedRole
from pulpcore.client.pulp_service.models.nested_role_response import NestedRoleResponse
from pulpcore.client.pulp_service.models.object_roles_response import ObjectRolesResponse
from pulpcore.client.pulp_service.models.paginated_task_response_list import PaginatedTaskResponseList
from pulpcore.client.pulp_service.models.paginatedservice_feature_content_guard_response_list import PaginatedserviceFeatureContentGuardResponseList
from pulpcore.client.pulp_service.models.paginatedservice_vulnerability_report_response_list import PaginatedserviceVulnerabilityReportResponseList
from pulpcore.client.pulp_service.models.patchedservice_feature_content_guard import PatchedserviceFeatureContentGuard
from pulpcore.client.pulp_service.models.progress_report_response import ProgressReportResponse
from pulpcore.client.pulp_service.models.service_feature_content_guard import ServiceFeatureContentGuard
from pulpcore.client.pulp_service.models.service_feature_content_guard_response import ServiceFeatureContentGuardResponse
from pulpcore.client.pulp_service.models.service_vulnerability_report_response import ServiceVulnerabilityReportResponse
from pulpcore.client.pulp_service.models.storage_class_enum import StorageClassEnum
from pulpcore.client.pulp_service.models.task_response import TaskResponse
